@@ -2,7 +2,7 @@
 ** dcalc
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/15 21:17:20 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Calculates the corresponding block number between 'dls' and 'dd' images
 ** when given an 'dls' block number, it determines the block number it
@@ -52,7 +52,6 @@
 ** ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 **
 */
-#include "fs_tools.h"
 #include "fs_lib.h"
 
 FILE *logfp;
@@ -109,7 +108,7 @@ main(int argc, char **argv)
 
 	case 'd':
 	    type |= DCALC_DD;
-	    count = strtoul(optarg, &cp, 0);
+	    count = strtoull(optarg, &cp, 0);
 	    if (*cp || cp == optarg) {
 		fprintf(stderr, "Invalid address: %s\n", optarg);
 		usage();
@@ -132,7 +131,7 @@ main(int argc, char **argv)
 
 	case 's':
 	    type |= DCALC_SLACK;
-	    count = strtoul(optarg, &cp, 0);
+	    count = strtoull(optarg, &cp, 0);
 	    if (*cp || cp == optarg) {
 		fprintf(stderr, "Invalid address: %s\n", optarg);
 		usage();
@@ -143,7 +142,7 @@ main(int argc, char **argv)
 
 	case 'u':
 	    type |= DCALC_DLS;
-	    count = strtoul(optarg, &cp, 0);
+	    count = strtoull(optarg, &cp, 0);
 	    if (*cp || cp == optarg) {
 		fprintf(stderr, "Invalid address: %s\n", optarg);
 		usage();
