@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit
 **
-** $Date: 2005/03/15 21:17:20 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -28,7 +28,6 @@
  *	Yorktown Heights, NY 10598, USA
  */
 
-#include "fs_tools.h"
 #include "fs_lib.h"
 
 
@@ -45,7 +44,7 @@ atoblock(const char *str)
     if (*str == 0)
 	return (0);
 
-    addr = strtoul(str, &cp, 0);
+    addr = strtoull(str, &cp, 0);
     if (*cp || cp == str)
 	error("bad block number: %s", str);
 
@@ -180,7 +179,7 @@ main(int argc, char **argv)
 	    /* We have a dash, but it could be part of the file name */
 	    *dash = '\0';
 
-	    bstart = strtoul(argv[argc - 1], &cp, 0);
+	    bstart = strtoull(argv[argc - 1], &cp, 0);
 	    if (*cp || cp == argv[argc - 1]) {
 		/* Not a number - consider it a file name */
 		*dash = '-';
@@ -192,7 +191,7 @@ main(int argc, char **argv)
 	    else {
 		/* Check after the dash */
 		dash++;
-		blast = strtoul(dash, &cp, 0);
+		blast = strtoull(dash, &cp, 0);
 		if (*cp || cp == dash) {
 		    /* Not a number - consider it a file name */
 		    dash--;
