@@ -2,7 +2,7 @@
 ** dstat
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/15 21:17:21 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Get the details about a data unit
 **
@@ -40,10 +40,8 @@
 ** ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 **
 */
-#include "fs_tools.h"
 #include "fs_lib.h"
 
-
 FILE *logfp;
 
 void
@@ -115,7 +113,7 @@ main(int argc, char **argv)
     }
 
     /* Get the address */
-    addr = strtoul(argv[argc - 1], &cp, 0);
+    addr = strtoull(argv[argc - 1], &cp, 0);
     if (*cp || cp == argv[argc - 1]) {
 	fprintf(stderr, "Invalid address\n");
 	usage();
