@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/15 21:17:21 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -27,8 +27,6 @@
 #include "fs_types.h"
 #include "ext2fs.h"
 
-#include "mymalloc.h"
-#include "error.h"
 
 /* ext2fs_group_lookup - look up group descriptor info */
 
