@@ -2,7 +2,7 @@
 ** ext2fs_dent
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/04 05:41:26 $
+** $Date: 2005/03/25 01:55:23 $
 **
 ** Human Interface Layer Support for an EXT2FS image
 **
@@ -137,10 +137,31 @@ ext2fs_dent_copy(EXT2FS_INFO * ext2fs, char *ext2_dent, FS_DENT * fs_dent)
     fs_dent->path = dirs;
     fs_dent->pathdepth = depth;
 
-    /* replace non-printable with . */
+    /* replace non-printable with ^. */
     for (i = 0; i < fs_dent->namlen; i++) {
-	if (isprint((int) fs_dent->name[i]) == 0)
-	    fs_dent->name[i] = '.';
+
+	if (isprint((int) fs_dent->name[i]) == 0) {
+
+	    /* Our buffer is EXT2FS_MAXNAMLEN + 1 */
+	    if (fs_dent->namlen < EXT2FS_MAXNAMLEN) {
+		int a;
+		fs_dent->name[fs_dent->namlen + 2] = '\0';
+		for (a = fs_dent->namlen; a > i; a--) {
+		    fs_dent->name[a + 1] = fs_dent->name[a];
+		}
+		if (isprint((int) (fs_dent->name[i] & 0x7f))) {
+		    fs_dent->name[i + 1] = fs_dent->name[i] & 0x7f;
+		}
+		else {
+		    fs_dent->name[i + 1] = '.';
+		}
+		fs_dent->name[i] = '^';
+		fs_dent->namlen++;
+	    }
+	    else {
+		fs_dent->name[i] = '.';
+	    }
+	}
     }
 
     if ((fs != NULL) && (fs_dent->inode)) {
