@@ -3,7 +3,7 @@
 ** ext2fs_journal
 ** The Sleuth Kit 
 **
-** $Date: 2005/01/17 22:40:16 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Journaling code for EXT3FS image
 **
@@ -44,8 +44,6 @@
 
 #include "fs_tools.h"
 #include "ext2fs.h"
-#include "mymalloc.h"
-#include "error.h"
 
 
 
