@@ -2,7 +2,7 @@
 ** fatfs
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/13 18:43:45 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Content and meta data layer support for the FAT file system 
 **
@@ -18,8 +18,6 @@
 #include "fs_types.h"
 #include "fatfs.h"
 
-#include "mymalloc.h"
-#include "error.h"
 
 
 /*
