@@ -2,7 +2,7 @@
 ** fatfs_dent
 ** The Sleuth Kit 
 **
-** $Date: 2005/01/17 22:40:16 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Human interface Layer support for the FAT file system
 **
@@ -16,8 +16,6 @@
 
 #include "fs_tools.h"
 #include "fatfs.h"
-#include "mymalloc.h"
-#include "error.h"
 
 /*
  * DESIGN NOTES
