@@ -2,7 +2,7 @@
 ** ffind  (file find)
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/15 21:17:21 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Find the file that uses the specified inode (including deleted files)
 ** 
@@ -49,9 +49,7 @@
 ** ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 **
 */
-#include "fs_tools.h"
 #include "fs_lib.h"
-#include "error.h"
 
 /* NTFS has an optimized version of this function */
 extern void ntfs_find_file(FS_INFO *, INUM_T, uint32_t, uint32_t, int,
@@ -164,19 +162,19 @@ main(int argc, char **argv)
 	    *dash2 = '\0';
 	    dash2++;
 
-	    id = strtoul(dash2, &cp, 0);
+	    id = strtoull(dash2, &cp, 0);
 	    if (*cp || cp == dash2) {
 		fprintf(stderr, "Invalid id in inode: %s\n", dash2);
 		usage();
 	    }
 	}
-	type = strtoul(dash, &cp, 0);
+	type = strtoull(dash, &cp, 0);
 	if (*cp || cp == dash) {
 	    fprintf(stderr, "Invalid type in inode: %s\n", dash);
 	    usage();
 	}
     }
-    inode = strtoul(argv[argc - 1], &cp, 0);
+    inode = strtoull(argv[argc - 1], &cp, 0);
     if (*cp || cp == argv[argc - 1]) {
 	fprintf(stderr, "Invalid inode address: %s\n", argv[argc - 1]);
 	usage();
