@@ -2,7 +2,7 @@
 ** ffs_dent
 ** The  Sleuth Kit 
 **
-** $Date: 2005/03/04 05:41:26 $
+** $Date: 2005/03/25 01:55:23 $
 **
 ** Human Interface Layer Support for a FFS image 
 **
@@ -117,12 +117,34 @@ ffs_dent_copy(FFS_INFO * ffs, char *ffs_dent, FS_DENT * fs_dent)
     fs_dent->path = dirs;
     fs_dent->pathdepth = depth;
 
-    /* Replace non-printable with a . */
+    /* replace non-printable with ^. */
     for (i = 0; i < fs_dent->namlen; i++) {
-	if (isprint((int) fs_dent->name[i]) == 0)
-	    fs_dent->name[i] = '.';
+
+	if (isprint((int) fs_dent->name[i]) == 0) {
+
+	    /* Our buffer is FFS_MAXNAMLEN + 1 */
+	    if (fs_dent->namlen < FFS_MAXNAMLEN) {
+		int a;
+		fs_dent->name[fs_dent->namlen + 2] = '\0';
+		for (a = fs_dent->namlen; a > i; a--) {
+		    fs_dent->name[a + 1] = fs_dent->name[a];
+		}
+		if (isprint((int) (fs_dent->name[i] & 0x7f))) {
+		    fs_dent->name[i + 1] = fs_dent->name[i] & 0x7f;
+		}
+		else {
+		    fs_dent->name[i + 1] = '.';
+		}
+		fs_dent->name[i] = '^';
+		fs_dent->namlen++;
+	    }
+	    else {
+		fs_dent->name[i] = '.';
+	    }
+	}
     }
 
+
     if ((fs != NULL) && (fs_dent->inode)) {
 	/* Get inode */
 	if (fs_dent->fsi)
