@@ -2,7 +2,7 @@
 ** fls
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/15 21:17:21 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Given an image and directory inode, display the file names and 
 ** directories that exist (both active and deleted)
@@ -50,10 +50,8 @@
 **
 */
 
-#include "fs_tools.h"
 #include "fs_lib.h"
 
-
 void
 usage()
 {
@@ -228,7 +226,7 @@ main(int argc, char **argv)
      *
      * Check the final argument and see if it is a number
      */
-    inode = strtoul(argv[argc - 1], &cp, 0);
+    inode = strtoull(argv[argc - 1], &cp, 0);
     if (*cp || cp == argv[argc - 1]) {
 	/* Not an inode at the end */
 	img =
