@@ -2,7 +2,7 @@
 ** fs_tools
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/04 05:41:26 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -14,6 +14,9 @@
 ** Corporation and others. All Rights Reserved.
 */
 
+#ifndef _FS_TOOLS_H
+#define _FS_TOOLS_H
+
  /*
   * External interface.
   */
@@ -424,6 +427,7 @@ extern FS_INFO *swapfs_open(IMG_INFO *, unsigned char ftype);
 	guess_end_u32(&(fs->endian), (x), (mag))
 
 
+#endif
 
 /* LICENSE
  * .ad
