@@ -2,7 +2,7 @@
 ** icat 
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/15 21:17:21 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -22,10 +22,8 @@
  *	Yorktown Heights, NY 10598, USA
  --*/
 
-#include "fs_tools.h"
 #include "fs_lib.h"
 
-
 FILE *logfp;
 
 /* usage - explain and terminate */
@@ -111,7 +109,7 @@ main(int argc, char **argv)
     /* Get the inode address */
     /* simple inode usage */
     if ((dash = strchr(argv[argc - 1], '-')) == NULL) {
-	inum = strtoul(argv[argc - 1], &cp, 0);
+	inum = strtoull(argv[argc - 1], &cp, 0);
 	if (*cp || cp == argv[argc - 1]) {
 	    fprintf(stderr, "Invalid inode address: %s\n", argv[argc - 1]);
 	    usage();
@@ -131,7 +129,7 @@ main(int argc, char **argv)
 	    *dash2 = '\0';
 	    dash2++;
 
-	    id = strtoul(dash2, &cp, 0);
+	    id = strtoull(dash2, &cp, 0);
 	    id_used = 1;
 	    if (*cp || cp == dash2) {
 		fprintf(stderr, "Invalid id in inode\n");
@@ -139,13 +137,13 @@ main(int argc, char **argv)
 	    }
 	}
 
-	inum = strtoul(argv[argc - 1], &cp, 0);
+	inum = strtoull(argv[argc - 1], &cp, 0);
 	if (*cp || cp == argv[argc - 1]) {
 	    fprintf(stderr, "Invalid inode address: %s\n", argv[argc - 1]);
 	    usage();
 	}
 
-	type = strtoul(dash, &cp, 0);
+	type = strtoull(dash, &cp, 0);
 	if (*cp || cp == dash) {
 	    fprintf(stderr, "Invalid type in inode\n");
 	    usage();
@@ -165,7 +163,7 @@ main(int argc, char **argv)
 	fs_icat(fs, 0, inum, type, id, flags | FS_FLAG_FILE_NOID);
 
     fs->close(fs);
-    img->close(fs);
+    img->close(img);
 
     exit(0);
 }
