@@ -2,7 +2,7 @@
 ** istat
 ** The Sleuth Kit 
 **
-** $Date: 2005/01/17 22:40:16 $
+** $Date: 2005/03/25 03:12:34 $
 **
 ** Display all inode info about a given inode.
 **
@@ -50,7 +50,7 @@
 **
 */
 
-#include "fs_tools.h"
+#include "fs_lib.h"
 
 FILE *logfp;
 
@@ -74,7 +74,7 @@ atoinum(const char *str)
 	*dash = '\0';
     }
 
-    inum = strtoul(str, &cp, 0);
+    inum = strtoull(str, &cp, 0);
     if (*cp || cp == str)
 	error("bad inode number: %s", str);
     return (inum);
@@ -134,7 +134,7 @@ main(int argc, char **argv)
 	    fprintf(stderr, "Invalid argument: %s\n", argv[optind]);
 	    usage();
 	case 'b':
-	    numblock = strtoul(optarg, &cp, 0);
+	    numblock = strtoull(optarg, &cp, 0);
 	    if (*cp || cp == optarg || numblock < 1) {
 		fprintf(stderr,
 			"invalid argument: block count must be positive: %s\n",
