@@ -59,7 +59,7 @@ atoinum(const char *str)
     if ((dash = strchr(str, '-')) != NULL) {
 	*dash = '\0';
     }
-    inum = strtoul(str, &cp, 0);
+    inum = strtoull(str, &cp, 0);
     if (*cp || cp == str)
 	error("bad inode number: %s", str);
     return (inum);
@@ -139,12 +139,12 @@ main(int argc, char **argv)
 	usage();
     }
 
-    blk = strtoul(argv[argc - 1], &cp, 0);
+    blk = strtoull(argv[argc - 1], &cp, 0);
     if (*cp || cp == argv[argc - 1])
 	error("bad block number: %s", argv[argc - 1]);
 
     /* Do we have an inode as well? */
-    inum = strtoul(argv[argc - 2], &cp, 0);
+    inum = strtoull(argv[argc - 2], &cp, 0);
     if (*cp || cp == argv[argc - 2]) {
 	/* Not a number therefore an image */
 
