@@ -59,7 +59,7 @@ atoinum(const char *str)
     if ((dash = strchr(str, '-')) != NULL) {
 	*dash = '\0';
     }
-    inum = strtoul(str, &cp, 0);
+    inum = strtoull(str, &cp, 0);
     if (*cp || cp == str)
 	error("bad inode number: %s", str);
     return (inum);
@@ -139,7 +139,7 @@ main(int argc, char **argv)
      *
      * Check the final argument and see if it is a number
      */
-    inum = strtoul(argv[argc - 1], &cp, 0);
+    inum = strtoull(argv[argc - 1], &cp, 0);
     if (*cp || cp == argv[argc - 1]) {
 	/* Not an inode at the end */
 	img =
