@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2005/03/04 17:17:02 $
+ * $Date: 2005/03/25 02:35:44 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved 
@@ -38,7 +38,7 @@ struct IMG_INFO {
     /* Read random */
      OFF_T(*read_random) (IMG_INFO *, char *, OFF_T, OFF_T);
      OFF_T(*get_size) (IMG_INFO *);
-    void (*close) ();
+    void (*close) (IMG_INFO *);
     void (*imgstat) (IMG_INFO *, FILE *);
 };
 
