@@ -1,5 +1,5 @@
 /*
- * $Date: 2005/03/07 16:55:05 $
+ * $Date: 2005/04/08 18:01:21 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved
@@ -266,7 +266,8 @@ split_open(OFF_T offset, int num_img, const char **images, IMG_INFO * next)
     int i;
 
     if (next != NULL) {
-	fprintf(stderr, "Invalid image layers - split must be lowest layer\n");
+	fprintf(stderr,
+		"Invalid image layers - split must be lowest layer\n");
 	exit(1);
     }
 
